@@ -1,10 +1,10 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "fxrd-mode" "1.0"
+(define-package "fxrd-mode" "20250705.116"
   "Major mode for editing fixed field width files."
   '((s "1.2"))
   :url "https://github.com/msherry/fxrd-mode"
-  :commit "795b969346982b75e24b5c8619b46197982fbb4d"
-  :revdesc "1.0-0-g795b96934698"
+  :commit "7f755e1ff4a6451bc97fcefef8e96f563311fb1a"
+  :revdesc "7f755e1ff4a6"
   :keywords '("convenience")
   :authors '(("Marc Sherry" . "(msherry@gmail.com)"))
   :maintainers '(("Marc Sherry" . "(msherry@gmail.com)")))
